var generators = require('yeoman-generator'),
    yosay = require('yosay'),
    chalk = require('chalk'),
    fs = require('fs-extra'),
    glob = require('glob'),
    replaceall = require('replaceall'),
    replace = require('replace'),
    sr = require('simple-random/browser');

module.exports = generators.Base.extend({
  prompting: function () {
    var done = this.async();

    // have Yeoman greet the user
    this.log(yosay("Hello, you're about to " + chalk.green("create a new Acquia BLT project!") + ",  First answer some simple questions."));

    var prompts = [

      {
        type: 'input',
        name: 'blt_human_name',
        message: 'What is the human readable project name?',
        default: 'My BLT Project'
      },
      {
        type: 'input',
        name: 'blt_project',
        message: 'What is the project name?',
        default: replaceall(' ', '-', this.appname)
      },
      {
        type: 'input',
        name: 'blt_prefix',
        message: 'What is the project prefix?',
        default: 'BLT'
      },
      {
        type: 'input',
        name: 'blt_domain',
        message: 'What is the domain name for the project?',
        default: replaceall(' ', '-', this.appname) + '.local'
      },
      {
        type: 'input',
        name: 'blt_profile',
        message: 'What is the drupal profile for the project?',
        default: 'thunder'
      },
      {
        type: 'input',
        name: 'blt_db_host',
        message: 'What is the database host for the project?',
        default: 'localhost'
      },
      {
        type: 'input',
        name: 'blt_db_port',
        message: 'What is the database port for the project?',
        default: '3306'
      },
      {
        type: 'input',
        name: 'blt_db_name',
        message: 'What is the database name for the project?',
        default: 'drupal'
      },
      {
        type: 'input',
        name: 'blt_db_user',
        message: 'What is the database username for the project?',
        default: 'root'
      },
      {
        type: 'input',
        name: 'blt_db_pass',
        message: 'What is the database password for the project?'
      },


    ];

    this.prompt(prompts, function (props) {
      this.props = props;
      done();
    }.bind(this));

  },

  writing: {
    app: function() {

      var self = this;
      var bltTemplatePath = self.templatePath() + '/blt';
      var files = glob.sync(bltTemplatePath + '/**/*');

      files.forEach(function(file) {
        if (fs.lstatSync(file).isDirectory()) {
          // Don't try to copy a directory, they get created automatically.
          return;
        }

        self.fs.copy(file, self.destinationPath(file.replace(bltTemplatePath + '/', '')));

      });

      // Create local.drushrc.php
      self.fs.copyTpl(
          bltTemplatePath + '/template/docroot/sites/default/default.local.drushrc.php',
          self.destinationPath(self.destinationRoot() + '/docroot/sites/default/local.drushrc.php'),
          {
            blt_domain: self.props.blt_domain,
          }
      );

      // Create local.settings.php
      self.fs.copyTpl(
          bltTemplatePath + '/template/docroot/sites/default/settings/default.local.settings.php',
          self.destinationPath(self.destinationRoot() + '/docroot/sites/default/settings/local.settings.php'),
          {
            blt_db_name: self.props.blt_db_name,
            blt_db_user: self.props.blt_db_user,
            blt_db_pass: self.props.blt_db_pass,
            blt_db_host: self.props.blt_db_host,
            blt_db_port: self.props.blt_db_port
          }
      );

      // Create project.yml
      self.fs.copy(
          bltTemplatePath + '/template/project.yml',
          self.destinationPath(self.destinationRoot() + '/project.yml'),
          {
            blt_project: self.props.blt_project,
            blt_human_name: self.props.blt_human_name,
            blt_profile: self.props.blt_profile,
            blt_hash_salt: sr({ length: 55, secure: true})
          }
      );

    }
  },

  install: function () {
    this.spawnCommand('composer', ['install']);
  }
  
});